# L2P PostgreSQL Image

This is a simple customised PostgreSQL image that can be used as a
containerised database for L2P applications.

## Requirements

* [Docker](https://www.docker.com/)

## Installation

Install Docker.

Build the customised PostgreSQL docker image.

```bash
# build l2p/postgres image
docker build -t l2p/postgres .
```

## Usage

### Development

Specify a database service that uses this image and set the `L2P_DB`
and `L2P_DB_USER` environment variables. To persist the data across
containers, specify a volume.

``` yaml
services:
  db:
    image: l2p/postgres
    environment:
       L2P_DB: l2p
       L2P_DB_USER: l2p
    volumes:
      - db_data:/var/lib/postgresql/data

volumes:
  db_data:
```

To reinitialise the database simply delete this volume.

``` bash
docker volume ls                # find the name
docker volume rm <name>
```

### Production

``` yaml
services:
  db:
    environment:
      PRODUCTION: 'true'
      POSTGRES_PASSWORD_FILE: /run/secrets/l2p_db_root_password
      L2P_DB_USER_PASSWORD_FILE: /run/secrets/l2p_db_user_password
    secrets:
      - l2p_db_root_password
      - l2p_db_user_password
    networks:
      - net
    volumes:
      - db_data_backups:/backups

networks:
  net:

secrets:
  l2p_db_root_password:
    external: true
  l2p_db_user_password:
    external: true

volumes:
  web_static:
  db_data_backups:
```
