#!/bin/bash
set -e

# file_env taken from official PostgreSQL Docker image.
# https://github.com/docker-library/postgres/blob/master/10/docker-entrypoint.sh
# usage: file_env VAR [DEFAULT]
#    ie: file_env 'XYZ_DB_PASSWORD' 'example'
# (will allow for "$XYZ_DB_PASSWORD_FILE" to fill in the value of
#  "$XYZ_DB_PASSWORD" from a file, especially for Docker's secrets feature)
file_env() {
	local var="$1"
	local fileVar="${var}_FILE"
	local def="${2:-}"
	if [ "${!var:-}" ] && [ "${!fileVar:-}" ]; then
		echo >&2 "error: both $var and $fileVar are set (but are exclusive)"
		exit 1
	fi
	local val="$def"
	if [ "${!var:-}" ]; then
		val="${!var}"
	elif [ "${!fileVar:-}" ]; then
		val="$(< "${!fileVar}")"
	fi
	export "$var"="$val"
	unset "$fileVar"
}

file_env 'L2P_DB_USER_PASSWORD'

if [ "$L2P_DB_USER_PASSWORD" ]; then
	pass="PASSWORD '$L2P_DB_USER_PASSWORD'"
    echo "$L2P_DB_USER password set"
else
    pass=
    echo "$L2P_DB_USER password NOT set"
    if [ "$PRODUCTION" = true ]; then
       echo "Error $L2P_DB_USER password must be set in production!" 1>&2
       exit 3
    fi
fi

psql -v ON_ERROR_STOP=1 --username "$POSTGRES_USER" <<-EOSQL
    CREATE USER "$L2P_DB_USER" WITH CREATEDB $pass;
    CREATE DATABASE "$L2P_DB";
    GRANT ALL PRIVILEGES ON DATABASE "$L2P_DB" TO "$L2P_DB_USER";
EOSQL
